@@ -1,20 +1,18 @@
 import search4file
 from faker import Faker
 import pandas as pd
-from alive_progress import alive_bar
 
 import os
 from pathlib import Path
 from openpyxl import load_workbook
-import warnings
 
 from pofile import get_files
+from poprogress import simple_progress
 from tqdm import tqdm
 from pathlib import Path
 # 忽略waring警告
 from poexcel.lib import pandas_mem
 from poexcel.lib.excel import SplitExcel
-from win32com.client import DispatchEx
 import xlwings as xw
 
 
@@ -29,27 +27,25 @@ class MainExcel():
                 path：输出excel的位置，有默认值
         """
         # 可以选择英语
-        if language.lower() == 'english':
-            language = 'en_US'
-        else:
-            language = 'zh_CN'
+        language = 'en_US' if language.lower() == 'english' else 'zh_CN'
+        #     language = 'en_US'
+        # else:
+        #     language =
         # 开始造数
         fake = Faker(language)
         excel_dict = {}
-        with alive_bar(len(columns) * rows) as bar:
-            for column in columns:
-                excel_dict[column] = list()
-                # excel_dict[column] = map(lambda x: eval('fake.{func}()'.format(func=x)), [column] * rows) # 使用map，会报错
-                while len(excel_dict[column]) < rows:
-                    excel_dict[column].append(eval('fake.{func}()'.format(func=column)))
-                    bar()
-            # 用pandas，将模拟数据，写进excel里面
-            writer = pd.ExcelWriter(path)
-            data = pd.DataFrame(excel_dict)
-            data = pandas_mem.reduce_pandas_mem_usage(data)
-            data.to_excel(writer, index=False)
-            # writer.save()
-            writer.close()
+        # with alive_bar(len(columns) * rows) as bar:
+        for column in simple_progress(columns, desc=f'columns'):
+            excel_dict[column] = list()
+            for _ in simple_progress(range(0, rows), desc='rows'):
+                excel_dict[column].append(eval('fake.{func}()'.format(func=column)))
+        # 用pandas，将模拟数据，写进excel里面
+        res_excel_file = pd.ExcelWriter(str(Path(path).absolute()))
+        res_data = pd.DataFrame(excel_dict)
+        res_data = pandas_mem.reduce_pandas_mem_usage(res_data)
+        res_data.to_excel(res_excel_file, index=False)
+        # writer.save()
+        res_excel_file.close()
 
     def merge2excel(self, dir_path, output_file, xlsxSuffix=".xlsx"):
         """
