@@ -1,13 +1,10 @@
 import unittest
-from pathlib import Path
-
-import pandas as pd
 from poexcel.api.excel import *
-import os
+
 
 class TestExcel(unittest.TestCase):
     def test_fake2excel(self):
-        fake2excel(language='fdsa')
+        fake2excel(language='fdsa', columns=['name', 'text'], rows=200)
 
     def test_split_excel_by_column(self):
         split_excel_by_column(filepath=r'../../contributors/bulabean/sedemo.xls',
